@@ -1,13 +1,17 @@
-#include <zypp-proto/commit.pb.h>
+#include <zypp-proto/target/commit.pb.h>
 #include <zypp-core/zyppng/core/ByteArray>
-#include <zypp-core/zyppng/rpc/rpc.h>
+#include <zypp-core/zyppng/rpc/messagestream.h>
 #include <zypp-core/zyppng/base/private/linuxhelpers_p.h>
 #include <zypp-core/AutoDispose.h>
 #include <zypp-core/Pathname.h>
 #include <zypp-core/fs/PathInfo.h>
+#include <zypp-core/ShutdownLock_p.h>
 #include <zypp-core/base/String.h>
 #include <zypp-core/base/StringV.h>
 
+#include <boost/interprocess/sync/file_lock.hpp>
+#include <mutex>
+
 // we do not link against libzypp, but these are pure header only files, if that changes
 // a copy should be created directly in the zypp-rpm project
 #include <zypp/target/rpm/librpm.h>
@@ -68,7 +72,7 @@ void rpmpsPrintToStream ( Stream &str, rpmps ps )
   if ( !ps )
     return;
 
-  rpmProblem p;
+  rpmProblem p = nullptr;
   zypp::AutoDispose<rpmpsi> psi ( ::rpmpsInitIterator(ps), ::rpmpsFreeIterator );
   while ((p = rpmpsiNext(psi))) {
     zypp::AutoFREE<char> msg( rpmProblemString(p) );
@@ -96,11 +100,12 @@ bool sendBytes ( int fd, const void *buf, size_t n ) {
 template <typename Message>
 bool pushMessage ( const Message &msg ) {
 
-  zypp::proto::Envelope env;
+  zyppng::RpcMessage env;
   env.set_messagetypename( msg.GetTypeName() );
-  msg.SerializeToString( env.mutable_value() );
+  env.set_value( msg.SerializeAsString() );
+  //msg.SerializeToString( env.mutable_value() );
 
-  const auto &str = env.SerializeAsString();
+  const auto &str = env.serialize();
   zyppng::rpc::HeaderSizeType msgSize = str.length();
   if ( !sendBytes( static_cast<int>( ExpectedFds::MessageFd ), reinterpret_cast< void* >( &msgSize), sizeof (zyppng::rpc::HeaderSizeType) ) )
     return false;
@@ -114,7 +119,7 @@ bool pushTransactionErrorMessage ( rpmps ps )
 
   zypp::proto::target::TransactionError err;
 
-  rpmProblem p;
+  rpmProblem p = nullptr;
   zypp::AutoDispose<rpmpsi> psi ( ::rpmpsInitIterator(ps), ::rpmpsFreeIterator );
   while ((p = rpmpsiNext(psi))) {
     zypp::AutoFREE<char> msg( rpmProblemString(p) );
@@ -182,7 +187,7 @@ int main( int, char ** )
   }
 
   // make sure the expected FDs are around too
-  struct stat sb;
+  struct stat sb{};
   if ( fstat( static_cast<int>(ExpectedFds::MessageFd), &sb) == -1 ) {
     ZERR << "Expected message fd is not valid, aborting" << std::endl;
     return OtherError;
@@ -224,6 +229,46 @@ int main( int, char ** )
 
   }
 
+  // create or fill a pid file, if there is a existing one just take it over
+  // if we reach this place libzypp has its global lock and made sure there is
+  // no still running zypp-rpm instance. So no need to do anything complicated.
+  using namespace boost::interprocess;
+  struct s_lockinfo {
+    s_lockinfo() = default;
+    s_lockinfo( s_lockinfo && ) = default;
+    s_lockinfo( const s_lockinfo & ) = delete;
+    s_lockinfo &operator= ( s_lockinfo && ) = default;
+    s_lockinfo &operator= ( const s_lockinfo & ) = delete;
+
+    ~s_lockinfo() {
+      std::scoped_lock<file_lock> lock(fileLock);
+      clearerr( lockFile );
+      ftruncate( fileno (lockFile), 0 );
+      fflush( lockFile );
+    }
+
+    file_lock fileLock;
+    zypp::AutoFILE lockFile;
+  };
+  std::optional<s_lockinfo> lockinfo;
+  if ( !msg.lockfilepath ().empty () ) {
+    lockinfo.emplace();
+    zypp::Pathname lockFileName = zypp::Pathname( msg.lockfilepath() ) / "zypp-rpm.pid";
+    lockinfo->lockFile = std::fopen( lockFileName.c_str(), "w");
+    if ( lockinfo->lockFile == nullptr ) {
+      ZERR << "Failed to create zypp-rpm pidfile." << std::endl;
+      return FailedToCreateLock;
+    }
+
+    lockinfo->fileLock = file_lock ( lockFileName.c_str() );
+
+    std::scoped_lock<file_lock> lock(lockinfo->fileLock);
+    fprintf(lockinfo->lockFile, "%ld\n", (long)getpid() );
+    fflush( lockinfo->lockFile );
+  }
+
+  zypp::ShutdownLock lck("zypp-rpm", "Zypp commit running.");
+
   // we have all data ready now lets start installing
   // first we initialize the rpmdb
   int rc = ::rpmReadConfigFiles( NULL, NULL );
