@@ -5,6 +5,7 @@
 #include <zypp-core/base/Exception.h>
 #include <zypp-core/base/Logger.h>
 #include <zypp-core/AutoDispose.h>
+#include <zypp-core/zyppng/base/UnixSignalSource>
 
 namespace zyppng {
 
@@ -233,11 +234,10 @@ static gboolean  eventLoopIdleFunc ( gpointer user_data )
     if( dPtr->runIdleTasks() ) {
       return G_SOURCE_CONTINUE;
     }
+
+    g_source_unref ( dPtr->_idleSource );
+    dPtr->_idleSource = nullptr;
   }
-
-  g_source_unref ( dPtr->_idleSource );
-  dPtr->_idleSource = nullptr;
-
   return G_SOURCE_REMOVE;
 }
 
@@ -246,7 +246,7 @@ GlibWaitPIDData::GlibWaitPIDData( GPid pid  )
   source = g_child_watch_source_new( pid );
 }
 
-GlibWaitPIDData::GlibWaitPIDData(GlibWaitPIDData &&other)
+GlibWaitPIDData::GlibWaitPIDData(GlibWaitPIDData &&other)  noexcept
   : tag( other.tag )
   , source( other.source )
   , callback( std::move( other.callback ) )
@@ -262,7 +262,7 @@ GlibWaitPIDData::~GlibWaitPIDData()
   }
 }
 
-GlibWaitPIDData &GlibWaitPIDData::operator=(GlibWaitPIDData &&other)
+GlibWaitPIDData &GlibWaitPIDData::operator=(GlibWaitPIDData &&other)  noexcept
 {
   tag = other.tag;
   source = other.source;
@@ -509,7 +509,7 @@ bool EventDispatcher::waitForFdEvent( const int fd, int events , int &revents ,
         if ( timeout == -1 )
           continue;
 
-        timeout -= g_timer_elapsed( *timer, NULL );
+        timeout -= g_timer_elapsed( *timer, nullptr );
         if ( timeout < 0 ) timeout = 0;
         if ( timeout <= 0 )
           return false;
@@ -552,6 +552,19 @@ bool EventDispatcher::untrackChildProcess(int pid)
   return true;
 }
 
+UnixSignalSourceRef EventDispatcher::unixSignalSource()
+{
+  Z_D();
+  // lazy init
+  UnixSignalSourceRef r;
+  if ( d->_signalSource.expired ()) {
+    d->_signalSource = r = UnixSignalSource::create();
+  } else {
+    r = d->_signalSource.lock ();
+  }
+  return r;
+}
+
 bool EventDispatcher::run_once()
 {
   return g_main_context_iteration( d_func()->_ctx, false );
@@ -564,10 +577,10 @@ void EventDispatcher::invokeOnIdleImpl(EventDispatcher::IdleFunction &&callback)
   d->enableIdleSource();
 }
 
-void EventDispatcher::unrefLaterImpl(std::shared_ptr<void> &&ptr )
+void EventDispatcher::unrefLaterImpl( std::shared_ptr<void> &&ptr )
 {
   Z_D();
-  d->_unrefLater.push_back( std::forward< std::shared_ptr<void> >(ptr) );
+  d->_unrefLater.push_back( std::move(ptr) );
   d->enableIdleSource();
 }
 
