@@ -24,15 +24,28 @@ namespace zyppng {
     using WeakPtr = std::weak_ptr<AsyncDataSource>;
 
     static Ptr create ();
-    bool open ( int readFd = -1, int writeFd = -1 );
+    bool openFds ( const std::vector<int>& readFds, int writeFd = -1 );
     void close () override;
 
+    using IODevice::waitForReadyRead;
+
+    virtual void closeWriteChannel ();
+
     /*!
-     * Blocks the current event loop to wait until there are bytes available to read from the device
+     * Blocks the current event loop to wait until all bytes currently in the buffer have been written to
+     * the write fd.
      *
      * \note do not use until there is a very good reason, like event processing should not continue until readyRead was sent
      */
-    bool waitForReadyRead(int timeout);
+    bool waitForReadyRead(uint channel, int timeout) override;
+
+    /*!
+     * Blocks the current event loop to wait until all bytes currently in the buffer have been written to
+     * the write fd.
+     *
+     * \note do not use until there is a very good reason, like event processing should not continue until bytesWritten was sent
+     */
+    void flush ();
 
     /*!
      * Signal is emitted always when the write channel is closed.
@@ -46,27 +59,29 @@ namespace zyppng {
      * when the write side of a pipe is closed. All data still residing in the read buffer
      * can still be read.
      */
-    SignalProxy<void( AsyncDataSource::ChannelCloseReason )> sigReadFdClosed();
+    SignalProxy<void( uint, AsyncDataSource::ChannelCloseReason )> sigReadFdClosed();
 
     /*!
-     * Signal is emitted every time bytes have been written to the underlying fd.
-     * This can be used to track how much data was actually sent.
-     */
-    SignalProxy< void (std::size_t)> sigBytesWritten ();
-
-    /*!
-     * Returns true as long as the read channel was not closed ( e.g. sigReadFdClosed was emitted )
+     * Returns true as long as the default read channel was not closed ( e.g. sigReadFdClosed was emitted )
      */
     bool readFdOpen () const;
 
+    /*!
+     * Returns true as long as the given read channel was not closed ( e.g. sigReadFdClosed was emitted )
+     */
+    bool readFdOpen ( uint channel ) const;
+
   protected:
     AsyncDataSource (  );
-    off_t writeData(const char *data, off_t count) override;
-    off_t readData(char *buffer, off_t bufsize) override;
-    size_t rawBytesAvailable() const override;
+    AsyncDataSource( AsyncDataSourcePrivate &d );
+    int64_t writeData(const char *data, int64_t count) override;
 
   private:
     using IODevice::open;
+
+    int64_t readData( uint channel, char *buffer, int64_t bufsize ) override;
+    int64_t rawBytesAvailable( uint channel ) const override;
+    void readChannelChanged ( uint channel ) override;
   };
 }
 
