@@ -21,6 +21,7 @@
 #include <iosfwd>
 
 #include <zypp/ExternalProgram.h>
+#include <utility>
 #include <zypp-core/KVMap>
 
 namespace zypp {
@@ -33,20 +34,25 @@ namespace zypp {
      */
     struct MountEntry
     {
-        MountEntry(const std::string &source,
-                   const std::string &target,
-                   const std::string &fstype,
-                   const std::string &options,
+        MountEntry(std::string source,
+                   std::string target,
+                   std::string fstype,
+                   std::string options,
                    const int         dumpfreq = 0,
                    const int         passnum  = 0)
-            : src(source)
-            , dir(target)
-            , type(fstype)
-            , opts(options)
+            : src(std::move(source))
+            , dir(std::move(target))
+            , type(std::move(fstype))
+            , opts(std::move(options))
             , freq(dumpfreq)
             , pass(passnum)
         {}
 
+        /**
+         * Returns true if the src part points to a block device in /dev
+         */
+        bool isBlockDevice () const;
+
         std::string src;  //!< name of mounted file system
         std::string dir;  //!< file system path prefix
         std::string type; //!< filesystem / mount type
@@ -58,7 +64,7 @@ namespace zypp {
     /** \relates MountEntry
      * A vector of mount entries.
      */
-    typedef std::vector<MountEntry> MountEntries;
+    using MountEntries = std::vector<MountEntry>;
 
     /** \relates MountEntry Stream output */
     std::ostream & operator<<( std::ostream & str, const MountEntry & obj );
@@ -74,12 +80,12 @@ namespace zypp {
          * For passing additional environment variables
          * to mount
          **/
-        typedef ExternalProgram::Environment Environment;
+        using Environment = ExternalProgram::Environment;
 
         /**
          * Mount options. 'key' or 'key=value' pairs, separated by ','
          **/
-        typedef KVMap<kvmap::KVMapBase::CharSep<'=',','> > Options;
+        using Options = KVMap<kvmap::KVMapBase::CharSep<'=', ','>>;
 
     public:
 
@@ -137,6 +143,12 @@ namespace zypp {
         static MountEntries
         getEntries(const std::string &mtab = "");
 
+       /**
+        * Get the modification time of the /etc/mtab file.
+        * \return Modification time of the /etc/mtab file.
+        */
+        static time_t getMTime();
+
     private:
 #if LEGACY(1722)
         ExternalProgram * _bincompat1;
