@@ -51,7 +51,7 @@ namespace zypp
     DefaultIntegral<bool,false> read;
   };
 
-  typedef shared_ptr<FetcherIndex> FetcherIndex_Ptr;
+  using FetcherIndex_Ptr = shared_ptr<FetcherIndex>;
 
   /** std::set ordering (less semantic) */
   struct SameFetcherIndex
@@ -90,11 +90,12 @@ namespace zypp
     };
     ZYPP_DECLARE_FLAGS(Flags, Flag);
 
+    FetcherJob(const FetcherJob &) = default;
+    FetcherJob(FetcherJob &&) = default;
+    FetcherJob &operator=(const FetcherJob &) = default;
+    FetcherJob &operator=(FetcherJob &&) = default;
 
-    FetcherJob( const OnMediaLocation &loc )
-      : location(loc)
-      , flags(None)
-    {
+    FetcherJob(const OnMediaLocation &loc) : location(loc), flags(None) {
       //MIL << location << endl;
     }
 
@@ -110,7 +111,7 @@ namespace zypp
   };
 
   ZYPP_DECLARE_OPERATORS_FOR_FLAGS(FetcherJob::Flags);
-  typedef shared_ptr<FetcherJob> FetcherJob_Ptr;
+  using FetcherJob_Ptr = shared_ptr<FetcherJob>;
 
   std::ostream & operator<<( std::ostream & str, const FetcherJob_Ptr & obj )
   {
@@ -129,6 +130,11 @@ namespace zypp
   public:
     Impl();
 
+    Impl(const Impl &) = default;
+    Impl(Impl &&) = delete;
+    Impl &operator=(const Impl &) = delete;
+    Impl &operator=(Impl &&) = delete;
+
     ~Impl() {}
 
     void setOptions( Fetcher::Options options );
@@ -391,11 +397,11 @@ namespace zypp
     }
     catch ( const FileCheckException &e )
     {
-      ZYPP_RETHROW(e);
+      throw;  // let known exceptions bypass  silently
     }
     catch ( const Exception &e )
     {
-      ZYPP_RETHROW(e);
+      throw; // slet known exceptions bypass  silently
     }
     catch (...)
     {
@@ -652,7 +658,7 @@ namespace zypp
     SignatureFileChecker sigchecker;
 
     // build the name of the index and the signature
-    OnMediaLocation idxloc(resource);
+    const OnMediaLocation& idxloc(resource);
     OnMediaLocation sigloc(resource);
     OnMediaLocation keyloc(resource);
 
