@@ -11,6 +11,7 @@
 */
 #include <iostream>
 #include <sstream>
+#include <utility>
 
 #include <zypp/base/Gettext.h>
 #include <zypp/base/LogTools.h>
@@ -43,7 +44,7 @@ namespace zypp
     // some Helpers and Predicates
     /////////////////////////////////////////////////////////////////
 
-    bool isDependencyAttribute( sat::SolvAttr attr_r )
+    bool isDependencyAttribute( const sat::SolvAttr& attr_r )
     {
       static sat::SolvAttr deps[] = {
         SolvAttr::provides,
@@ -76,7 +77,7 @@ namespace zypp
         , _arch( arch )
       {}
 
-      bool operator()( sat::LookupAttr::iterator iter_r )
+      bool operator()( const sat::LookupAttr::iterator& iter_r )
       {
         if ( !_arch.empty() && iter_r.inSolvable().arch() != _arch )
           return false;
@@ -115,7 +116,7 @@ namespace zypp
         , _arch( arch )
       {}
 
-      bool operator()( sat::LookupAttr::iterator iter_r )
+      bool operator()( const sat::LookupAttr::iterator& iter_r )
       {
         if ( !_arch.empty() && iter_r.inSolvable().arch() != _arch )
           return false;
@@ -145,7 +146,7 @@ namespace zypp
         : _cap( cap_r )
       {}
 
-      bool operator()( sat::LookupAttr::iterator iter_r ) const
+      bool operator()( const sat::LookupAttr::iterator& iter_r ) const
       {
         return _cap.matches( iter_r.asType<Capability>() ) == CapMatch::yes;
       }
@@ -190,34 +191,34 @@ namespace zypp
      */
     struct AttrMatchData
     {
-      typedef function<bool(sat::LookupAttr::iterator)> Predicate;
+      using Predicate = function<bool (sat::LookupAttr::iterator)>;
 
-      static bool always( sat::LookupAttr::iterator ) { return true; }
-      static bool never( sat::LookupAttr::iterator ) { return false; }
+      static bool always( const sat::LookupAttr::iterator& ) { return true; }
+      static bool never( const sat::LookupAttr::iterator& ) { return false; }
 
       AttrMatchData()
       {}
 
       AttrMatchData( sat::SolvAttr attr_r )
-        : attr( attr_r )
+        : attr(std::move( attr_r ))
       {}
 
-      AttrMatchData( sat::SolvAttr attr_r, const StrMatcher & strMatcher_r )
-        : attr( attr_r )
-        , strMatcher( strMatcher_r )
+      AttrMatchData( sat::SolvAttr attr_r, StrMatcher  strMatcher_r )
+        : attr(std::move( attr_r ))
+        , strMatcher(std::move( strMatcher_r ))
       {}
 
-      AttrMatchData( sat::SolvAttr attr_r, const StrMatcher & strMatcher_r,
-                     const Predicate & predicate_r, const std::string & predicateStr_r )
-        : attr( attr_r )
-        , strMatcher( strMatcher_r )
-        , predicate( predicate_r )
-        , predicateStr( predicateStr_r )
+      AttrMatchData( sat::SolvAttr attr_r, StrMatcher  strMatcher_r,
+                     Predicate  predicate_r, std::string  predicateStr_r )
+        : attr(std::move( attr_r ))
+        , strMatcher(std::move( strMatcher_r ))
+        , predicate(std::move( predicate_r ))
+        , predicateStr(std::move( predicateStr_r ))
       {}
 
       /** A usable Predicate must provide a string serialization.
-       * As there is no \c operator== for \ref Predicate, we compare it's
-       * string representation instead. If you add new predicated, check the
+       * As there is no \c operator== for \ref Predicate, we compare its
+       * string representation instead. If you add new predicate, check the
        * deserialization code in \ref deserialize.
        */
       template<class TPredicate>
@@ -400,7 +401,7 @@ namespace zypp
       return false;
     }
 
-    typedef std::list<AttrMatchData> AttrMatchList;
+    using AttrMatchList = std::list<AttrMatchData>;
 
 
   } /////////////////////////////////////////////////////////////////
@@ -421,8 +422,12 @@ namespace zypp
       , _status_flags(ALL)
     {}
 
-    ~Impl()
-    {}
+    Impl(const Impl &) = default;
+    Impl(Impl &&) = delete;
+    Impl &operator=(const Impl &) = delete;
+    Impl &operator=(Impl &&) = delete;
+
+    ~Impl() {}
 
   public:
     /** String representation */
@@ -1053,7 +1058,7 @@ namespace zypp
   }
 
   void PoolQuery::execute(ProcessResolvable fnc)
-  { invokeOnEach( begin(), end(), fnc); }
+  { invokeOnEach( begin(), end(), std::move(fnc)); }
 
 
   /*DEPRECATED LEGACY:*/void PoolQuery::setRequireAll( bool ) {}
@@ -1146,7 +1151,7 @@ namespace zypp
   ///////////////////////////////////////////////////////////////////
 
 
-  //\TODO maybe ctor with stream can be usefull
+  //\TODO maybe ctor with stream can be useful
   //\TODO let it throw, let it throw, let it throw.
   bool PoolQuery::recover( std::istream &str, char delim )
   {
@@ -1275,7 +1280,7 @@ namespace zypp
       }
       else if ( attribute == PoolQueryAttr::editionAttr)
       {
-        std::string::size_type pos;
+        std::string::size_type pos = 0;
         Rel rel("==");
         if (attrValue.find_first_of("=<>!") == 0)
         {
@@ -1530,7 +1535,7 @@ namespace zypp
     class PoolQueryMatcher
     {
       public:
-        typedef sat::LookupAttr::iterator base_iterator;
+        using base_iterator = sat::LookupAttr::iterator;
 
       public:
         const base_iterator & end() const
@@ -1610,6 +1615,11 @@ namespace zypp
         }
 
       public:
+        PoolQueryMatcher(const PoolQueryMatcher &) = default;
+        PoolQueryMatcher(PoolQueryMatcher &&) = default;
+        PoolQueryMatcher &operator=(const PoolQueryMatcher &) = default;
+        PoolQueryMatcher &operator=(PoolQueryMatcher &&) = default;
+
         /** Ctor stores the \ref PoolQuery settings.
          * \throw MatchException Any of the exceptions thrown by \ref PoolQuery::Impl::compile.
          */
