@@ -58,7 +58,7 @@ namespace zypp
    *
    * \include n_ResPool_nomorenameiter
   */
-  class ResPool
+  class ZYPP_API ResPool
   {
     friend std::ostream & operator<<( std::ostream & str, const ResPool & obj );
 
@@ -472,7 +472,7 @@ namespace zypp
   ///////////////////////////////////////////////////////////////////
 
   /** \relates ResPool Stream output */
-  std::ostream & operator<<( std::ostream & str, const ResPool & obj );
+  std::ostream & operator<<( std::ostream & str, const ResPool & obj ) ZYPP_API;
 
   /////////////////////////////////////////////////////////////////
 } // namespace zypp
